@@ -5,6 +5,7 @@ import geopandas as gp
 from datetime import datetime
 from skimage.draw import line
 import matplotlib.pyplot as plt
+from matplotlib.widgets import LassoSelector
 from matplotlib.path import Path
 from math import radians, cos, sin, asin, sqrt, floor
 from shapely.geometry import LineString, Point, shape
@@ -112,14 +113,18 @@ def plot_matrix_select(matrix):
     plot = ax.imshow(matrix, interpolation='nearest', picker=True)
     plt.title("Manually select any cells which you want to remove from water classification.")
 
-    def onpick(event):
-        mouseevent = event.mouseevent
-        matrix[floor(mouseevent.ydata), floor(mouseevent.xdata)] = False
+    def onpick(verts):
+        selection = Path(verts)
+        extents = selection.get_extents()
+        for i in range(floor(extents.y0), floor(extents.y1) + 1):
+            for j in range(floor(extents.x0), floor(extents.x1) + 1):
+                if selection.contains_point((j, i)):
+                    matrix[i, j] = False
         plot.set_data(matrix)
         fig.canvas.draw()
         fig.canvas.flush_events()
 
-    fig.canvas.mpl_connect('pick_event', onpick)
+    lasso = LassoSelector(ax, onpick)
     plt.tight_layout()
     plt.show()
     return matrix
